@@ -39,7 +39,7 @@ plot.mm.s <- function(s, whichcells=NULL,
   }
 
   if (is.character(whichcells[1])) {
-    whichcells = names.to.indexes(names(s$spikes), whichcells)
+    whichcells = names.to.indexes(names(s$spikes), whichcells, allow.na=TRUE)
   }
 
   if (is.null(main)) {
@@ -78,33 +78,37 @@ plot.mm.s <- function(s, whichcells=NULL,
   for (cell in whichcells) {
     ts <- spikes[[cell]]                #get spike times.
     n <- length(ts)                     #number of spikes.
-    ys <- numeric(n) + ymin
-    
-    segments(ts, ys, ts, ys+deltay, lwd=0.2) #draw spikes.
 
-    ## simple test to see if bursts have been defined.
-    if (have.bursts) {
-      burst.times <- s$allb[[cell]]
-      if (!is.na(burst.times[1])) {
-        ## we have some vald burst info.
-        nbursts <- nrow(burst.times)
-        ##ys <- rep(ymin+deltay/2, nbursts)
+    if(n > 0) {
+      ## check we have spikes; e.g. cell could be NA
+      ys <- numeric(n) + ymin
+      
+      segments(ts, ys, ts, ys+deltay, lwd=0.2) #draw spikes.
 
-        ## alternate height of bursts so that we can sep adjacent bursts.
-        ys <- rep(ymin+deltay/2, nbursts)
-        shimmy <- deltay*0.25
-        odd <- (1:nbursts) %% 2 == 1
-        ys[odd] <- ys[odd] + shimmy
+      ## simple test to see if bursts have been defined.
+      if (have.bursts) {
+        burst.times <- s$allb[[cell]]
+        if (!is.na(burst.times[1])) {
+          ## we have some vald burst info.
+          nbursts <- nrow(burst.times)
+          ##ys <- rep(ymin+deltay/2, nbursts)
 
-        start.burst <- ts[burst.times[,"beg"]]
-        ## for the end of the burst, -1 is needed since if start spike
-        ## is 20, and i=3, last spike in burst is 22 (spikes 20, 21, 22)
-        end.burst <- ts[ burst.times[,"beg"] + burst.times[,"len"] -1]
-        segments(start.burst, ys,
-                 end.burst, ys,
-                 col="red", lwd=2)
-        text(start.burst, rep(ymin+deltay*1.1, nbursts),
-             labels=burst.times[,"len"], col="blue")
+          ## alternate height of bursts so that we can sep adjacent bursts.
+          ys <- rep(ymin+deltay/2, nbursts)
+          shimmy <- deltay*0.25
+          odd <- (1:nbursts) %% 2 == 1
+          ys[odd] <- ys[odd] + shimmy
+
+          start.burst <- ts[burst.times[,"beg"]]
+          ## for the end of the burst, -1 is needed since if start spike
+          ## is 20, and i=3, last spike in burst is 22 (spikes 20, 21, 22)
+          end.burst <- ts[ burst.times[,"beg"] + burst.times[,"len"] -1]
+          segments(start.burst, ys,
+                   end.burst, ys,
+                   col="red", lwd=2)
+          text(start.burst, rep(ymin+deltay*1.1, nbursts),
+               labels=burst.times[,"len"], col="blue")
+        }
       }
     }
     ymin <- ymin + yminadd
@@ -1236,7 +1240,8 @@ make.movieframes <- function (x, beg=1,
                               prefix="mea",
                               show.frames = interactive(),
                               seconds=TRUE,
-                              delete.first=FALSE,
+                              delete.first=TRUE,
+                              clean.after=FALSE,
                               anim.delay=0) {
 
   ## Loop over each frame, making a PNG (mono) file.
@@ -1294,6 +1299,8 @@ make.movieframes <- function (x, beg=1,
     plot.rate.mslayout(x, i)
     dev.off()
   }
+
+  cat(paste("Movie frames stored in", outputdir, "\n"))
   
   if (anim.delay > 0) {
     ## We want to make an animation...
@@ -1301,11 +1308,19 @@ make.movieframes <- function (x, beg=1,
       outputdir, anim.delay, prefix)
     ##browser()
     system(cmd)
+    cat(sprintf("Output file mea.gif created in %s\n", outputdir))
+
+    if (clean.after) {
+      ## remove all the temp files up afterwards
+      files <- list.files(path=outputdir, full.names=TRUE,
+                          pattern=paste(prefix,".*\\.png",sep=''))
+      if (length(files)>0)
+        file.remove(files)
+    }
+  } else {
+    cat("Convert these to a movie using Quicktime or on Linux:\n")
+    cat("convert -delay 20 *png mea.gif\n")
   }
-  
-  cat(paste("Movie frames stored in", outputdir, "\n"))
-  cat("Convert these to a movie using Quicktime or on Linux:\n")
-  cat("convert -delay 20 *png mea.gif\n")
 }
 
 time.to.frame <- function(times, time) {
